<?php

namespace Modules\Cadastros\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;

class Gql33000QualificacaoService
{
    protected $connection;
    
    public function __construct($entityManager, $environment)
    {
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    
    /* ****************
     *    INÍCIO      *
     ******************/
    
    public function getCodQualificacao($row) 
    {
		$param = array(
		    'P_CDQUALIF' => $row['CDQUALIF']
		);
		
        $query = "SELECT
                     CDQUALIF
                 FROM
                     QUALIFICACAO
                 WHERE
                     (CDQUALIF = :P_CDQUALIF)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            return $std->fetchAll();
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function getDescQualificacao($row) 
    {
		$param = array(
		    'P_DSQUALIF' => $row['DSQUALIF'],
		    'P_CDQUALIF' => $row['CDQUALIF']
		);
		
        $query = " SELECT
                   DSQUALIF
                FROM
                   QUALIFICACAO
                WHERE
                   (UPPER(DSQUALIF) = UPPER(:P_DSQUALIF)) AND
                   (CDQUALIF <> :P_CDQUALIF)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            return $std->fetchAll();
        } catch (Exception $e){
            throw $e;
        }
    }
    
    /* ***************
     *    INSERT     *
     *****************/
    
    public function insertQualificacao($row) 
    {
		$param = array(
		    'P_CDQUALIF'  => $row['CDQUALIF'],
		    'P_DSQUALIF'  => $row['DSQUALIF'],
		    'P_IDPERCOTCMP' => $row['IDPERCOTCMP']
		);
		
        $query = "INSERT INTO QUALIFICACAO
                     (CDQUALIF, DSQUALIF, IDPERCOTCMP)
                 VALUES
                     (:P_CDQUALIF, :P_DSQUALIF, :P_IDPERCOTCMP)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    /* ****************
     *    UPDATE      *
     ******************/
    
    public function updateQualificacao($row) 
    {
		$param = array(
		    'P_CDQUALIF'  => $row['CDQUALIF'],
		    'P_DSQUALIF' => $row['DSQUALIF'],  
		    'P_IDPERCOTCMP' => $row['IDPERCOTCMP']
		);
		
        $query = "UPDATE QUALIFICACAO
                  SET CDQUALIF = :P_CDQUALIF,
                    DSQUALIF = :P_DSQUALIF,
                    IDPERCOTCMP = :P_IDPERCOTCMP
                  WHERE CDQUALIF  = :P_CDQUALIF";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    /* ****************
     *    DELETE      *
     ******************/
    
    public function deleteQualificacao($row) 
    {
		$param = array(
		    'OLD_CDQUALIF'  => $row['CDQUALIF']
		);
		
        $query = "DELETE FROM QUALIFICACAO
                   WHERE CDQUALIF = :OLD_CDQUALIF";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e) {
            throw $e;
        }
    }
}